pub struct Scratchpad { /* private fields */ }Expand description
Adds bounded durable notes without exposing persistence details to the agent loop.
Implementations
Sourceimpl Scratchpad
impl Scratchpad
Sourcepub fn new(store: ScratchpadStore) -> Self
pub fn new(store: ScratchpadStore) -> Self
Creates scratchpad middleware backed by a shared concrete store.