Agent handles and the single linear command dispatch loop.
Structs
- Agent
- Bidirectional handle consumed by a frontend.
- Agent
Config - Dependencies and policy for one agent session.
- Agent
Sender - Cloneable command side of a running agent.
Functions
- create_
agent - Validates capabilities, restores a checkpoint, and starts the agent loop.